;------------------------------------------------------------------------------
; CAD Concepts
;  
; QUICK IMPRINT
; Reduces prompting to IMPRINT multiple entities
;
; Copyright (C) 2019 CAD Concepts Limited.
; 
; This program is free software: you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation, either version 3 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program.  If not, see <http://www.gnu.org/licenses/>. 
;------------------------------------------------------------------------------
;
; File        : QuickImprint.lsp
; Author      : Jason Bourhill
; Web					: http://www.cadconcepts.co.nz
; Date        : 08/01/2019
; CAD Ver(s)	: Bricscad
; 
; PURPOSE:
; To quickly IMPRINT multiple entities onto an object
;
; USAGE:
; To load type (load "QuickImprint.lsp") from the command line
; or drag and drop the file onto your drawing using explorer.
; 
; There is one command available:
; 
; QUICKIMPRINT
;
; 	COMMAND OPTIONS:
; 	After select entities to imprint, you will be prompted as to whether
; 	you want to delete or retain ALL the source imprint entities.
;
;------------------------------------------------------------------------------

(defun	C:QUICKIMPRINT ( / sset sset_imp DelSource)
 (acet-error-init  '(("CMDECHO" 0 ) 0 nil)) ; set error handler
 (princ "\nSelect a 3d solid, surface or region: ") ; prompt user
	(setq sset (ssget ":S" '((-4 . "<or")(0 . "3DSOLID")(0 . "SURFACE")(0 . "REGION")(-4 . "or>")))) ;  Filter selection to single 3d solid, surface or region.
	(Cond
		(sset
			(setq sset (ssname sset 0)) ; retrieve the selected entity to be imprinted
			(princ "\nSelect entities to imprint: ") ; prompt user
			(setq sset_imp (ssget))
			(cond
				(sset_imp
					(initget "Yes No")
					(setq DelSource (if (= "Yes" (getkword "\nDelete the source imprint objects [Yes/No] <No>: ")) "_Yes" "_No"))
					(foreach ent (vle-selectionset->list sset_imp) ; for each of our imprint entities
						(command "._IMPRINT" sset ent) ; imprint on our source object
						(if (wcmatch (getvar "CMDNAMES") "IMPRINT")(command DelSource "")) ; IMPRINT remains active if sucessful, provide answer on whether to delete imprint object and end command
					)
				)
				(T (princ "\nNo entities selected"))
			)
		)
		(T (princ "\nNo 3d solid, surface or region selected"))
	)
	(acet-error-restore) ; restore error
)